@@ -1,4 +1,5 @@
 from alfa_sdk.common.base import BaseClient
+from alfa_sdk.common.exceptions import ValidationError
 from alfa_sdk.secrets import SecretsClient
 from alfa_sdk.resources import (
     Algorithm,
@@ -71,3 +72,13 @@ class AlgorithmClient(BaseClient):
         algorithm = self.get_algorithm(algorithm_id)
         environment = algorithm.get_environment(environment)
         return environment.deploy(version, file_path, **kwargs)
+
+    #
+
+    def store_kpi(self, kpis, entity=None, time=None):
+        run_id = self.session.context.get('algorithmRunId')
+        environment = self.get_environment_from_context()
+        if environment is None:
+            raise ValidationError(error="AlgorithmEnvironmentId is not defined.")
+
+        return environment.store_kpi(kpis, entity, run_id, time)
