@@ -15,8 +15,7 @@ ALFA_APP_ID = 30
 
 class Authentication:
     user = None
-    access_token = None
-    auth0_token = None
+    token = None
 
     def __init__(self, credentials={}, *, alfa_env):
         endpoint = EndpointHelper(alfa_env=alfa_env)
@@ -25,54 +24,48 @@ class Authentication:
 
     def _authenticate(self, url_core, credentials):
         try:
-            access_token, auth0_token = fetch_tokens(credentials)
-            self.user = validate_token(url_core, access_token, auth0_token)
-            self.access_token = access_token
-            self.auth0_token = auth0_token
+            token = fetch_token(credentials)
+            self.user = validate_token(url_core, token)
+            self.token = token
         except:
             client_id, client_secret = fetch_credentials(credentials)
-            auth0_token = request_auth0_token(url_core, client_id, client_secret)
-            self.user = validate_token(url_core, None, auth0_token)
-            self.auth0_token = auth0_token
+            token = request_oauth_token(url_core, client_id, client_secret)
+            self.user = validate_token(url_core, token)
+            self.token = token
 
     def get_token(self):
-        if self.access_token:
-            return self.access_token, "access_token"
-        if self.auth0_token:
-            return self.auth0_token, "auth0_token"
+        if self.token:
+            return self.token
+
         raise TokenNotFoundError()
 
     def authenticate_request(self, options):
-        return authenticate_request(options, self.access_token, self.auth0_token)
+        return authenticate_request(options, self.token)
 
 
 #
 
 
-def fetch_tokens(credentials={}):
+def fetch_token(credentials={}):
     store = AuthStore.get_group()
     cache = AuthStore.get_group("cache")
 
-    if "access_token" not in credentials:
-        if "ALFA_ACCESS_TOKEN" in os.environ:
-            credentials["access_token"] = os.environ.get("ALFA_ACCESS_TOKEN")
-        elif store and "access_token" in store:
-            credentials["access_token"] = store["access_token"]
-        elif cache and "access_token" in cache:
-            credentials["access_token"] = cache["access_token"]
+    if "token" not in credentials:
+        if "ALFA_TOKEN" in os.environ:
+            credentials["token"] = os.environ.get("ALFA_TOKEN")
+        elif "ALFA_ACCESS_TOKEN" in os.environ:
+            credentials["token"] = os.environ.get("ALFA_ACCESS_TOKEN")
+        elif "ALFA_AUTH0_TOKEN" in os.environ:
+            credentials["token"] = os.environ.get("ALFA_AUTH0_TOKEN")
+        elif store and "token" in store:
+            credentials["token"] = store["token"]
+        elif cache and "token" in cache:
+            credentials["token"] = cache["token"]
 
-    if "auth0_token" not in credentials:
-        if "ALFA_AUTH0_TOKEN" in os.environ:
-            credentials["auth0_token"] = os.environ.get("ALFA_AUTH0_TOKEN")
-        elif store and "auth0_token" in store:
-            credentials["auth0_token"] = store["auth0_token"]
-        elif cache and "auth0_token" in cache:
-            credentials["auth0_token"] = cache["auth0_token"]
-
-    if "access_token" not in credentials and "auth0_token" not in credentials:
+    if "token" not in credentials:
         raise TokenNotFoundError()
 
-    return credentials.get("access_token"), credentials.get("auth0_token")
+    return credentials.get("token")
 
 
 def fetch_credentials(credentials={}):
@@ -98,7 +91,7 @@ def fetch_credentials(credentials={}):
 #
 
 
-def request_auth0_token(url_core, client_id, client_secret):
+def request_oauth_token(url_core, client_id, client_secret):
     url = url_core + "/api/ApiKeyValidators/requestToken"
 
     res = requests.post(
@@ -118,16 +111,13 @@ def request_auth0_token(url_core, client_id, client_secret):
     return token
 
 
-def validate_token(url_core, access_token, auth0_token=None):
-    if access_token:
-        url = url_core + "/api/WbUsers/getRole"
-    elif auth0_token:
-        url = url_core + "/api/ApiKeyValidators/validateTokenForApp"
-    else:
+def validate_token(url_core, token):
+    if not token:
         raise AuthenticationError(error="No tokens were supplied")
 
+    url = url_core + "/api/ApiKeyValidators/validateTokenForApp"
     options = {"params": {"appId": ALFA_APP_ID}}
-    options = authenticate_request(options, access_token, auth0_token)
+    options = authenticate_request(options, token)
     res = requests.get(url, **options)
     res = res.json()
 
@@ -137,20 +127,13 @@ def validate_token(url_core, access_token, auth0_token=None):
     return res
 
 
-def authenticate_request(options, access_token, auth0_token=None):
-    if not access_token and not auth0_token:
+def authenticate_request(options, token):
+    if not token:
         raise TokenNotFoundError()
 
-    if "params" not in options:
-        options["params"] = {}
     if "headers" not in options:
         options["headers"] = {}
 
-    if access_token:
-        options["headers"]["access_token"] = access_token
-        options["params"]["access_token"] = access_token
-    if auth0_token:
-        options["headers"]["wb-authorization"] = auth0_token
-
+    options["headers"]["wb-authorization"] = token
     return options
 
