@@ -15,5 +15,10 @@ class DataClient(BaseClient):
         res = requests.get(url["downloadLink"], allow_redirects=True)
         return res.content
 
-    def list_data_files(self):
-        return self.session.request("get", "data", "/api/Storages/list")
+    def list_data_files(self, prefix="", skip=0, limit=100, order="name ASC"):
+        return self.session.request(
+            "get",
+            "data",
+            "/api/Storages/list",
+            params={"prefix": prefix, "skip": skip, "limit": limit, "order": order},
+        )
